
; AutoIt Version: 3.0
; Language:       English
; Platform:       Win2000
; Author:         Samuel Murray (http://www.leuce.com/translate/)
;
; Script Function:
;   Extract an untranslated TM from OmegaT project files

; HOW TO USE

; You must have a file named omegat.prefs in the same folder as the script,
; with the following content (without the semicolons, of course):

; <?xml version="1.0" encoding="UTF-8" ?>
; <omegat>
;   <preference version="1.0">
;     <tab_advance>true</tab_advance>
;     <wf_noSourceText>false</wf_noSourceText>
;     <wf_insertBestMatch>false</wf_insertBestMatch>
;     <wf_allowTransEqualToSrc>true</wf_allowTransEqualToSrc>
;     <always_confirm_quit>false</always_confirm_quit>
;     <filters_version>1.6 RC12a</filters_version>
;   </preference>
; </omegat>

; Since the OmegaT installer for Windows doesn't write anything to the
; Windows registry, the script can't determine the path to the OmegaT
; Application Data folder, and therefore it assumes the default.
; If your OmegaT is installed in a different folder, search this script
; for "@AppDataDir" and change the script in those regions.

; THE SCRIPT

; You can press Alt+Ctrl+Q at any time to kill the script.

HotKeySet("!^q", "MyExit")

; Create a backup copy of user's prefs file:

FileCopy (@AppDataDir & "\OmegaT\omegat.prefs", @AppDataDir & "\OmegaT\omegat_prefs.rollback", 1)

; Exit script if user doesn't have project open:

$answer = MsgBox (0, "Confirm project is open", "Make sure the project from which you want to extract an untranslated TM, is currently open in OmegaT.  If not, open it and then click OK.")
WinSetOnTop ("Confirm project", "Make sure the", 1)

While 1
If $answer = 1 Then ExitLoop
WEnd

$notrunning = WinExists ("OmegaT", "")
If $notrunning = 0 Then Exit

; Check if Confirm Quit is enabled, and if so, disable it:

$file1 = FileOpen (@AppDataDir & "\OmegaT\omegat.prefs", 0)
$file2 = FileRead(@AppDataDir & "\OmegaT\omegat.prefs", FileGetSize(@AppDataDir & "\OmegaT\omegat.prefs"))
$file3 = StringSplit($file2, @CRLF, 1)
For $i = 1 To $file3[0]
If StringInStr ($file3[$i], "quit>true") Then
WinSetState ("OmegaT", "", @SW_RESTORE)
WinActivate ("OmegaT", "")
WinWaitActive ("OmegaT", "")
Sleep (500)
Send ("!o")
Sleep (500)
Send ("a")
EndIf
Next

WinSetState ("OmegaT", "", @SW_RESTORE)

; Wait until OmegaT is active:

WinActivate ("OmegaT", "")
WinWaitActive ("OmegaT", "")

; Open Project Properties and get path to \omegat\ folder:

Send ("^e")
Sleep (1000)
Send ("{TAB 6}")
Send ("{HOME}")
Send ("+{END}")
; Sleep (1000)
Send ("^c")

$clip1 = ClipGet()
$dfltomegat = StringReplace($clip1, "\source\", "\omegat\")

Send ("{ESC}")
WinActivate ("OmegaT", "")
WinWaitActive ("OmegaT", "")

; Get project name:

$omttitle = WinGetTitle ("OmegaT", "")
$omttitle2 = StringSplit($omttitle, ":: ", 1)
$projectname = $omttitle2[2]

$projectnamereal = InputBox ("Confirm folder name", "Please confirm the name of your current project", $projectname, "", 300, 200)

; Ask user to confirm path:

$dfltomegat2 = InputBox ("Confirm \omegat\ folder location", "Please confirm the location of your \omegat\ folder", $dfltomegat, "", 500, 200)

; Get total number of segments from project_stats.txt:

$projectstats = FileOpen ($dfltomegat2 & "project_stats.txt", 0)
$projectstats2 = FileReadLine ($projectstats, 4)
$projectstats3 = StringSplit($projectstats2, @TAB)
$numofsegments = $projectstats3[3]
FileClose($projectstats)

; Ask user to confirm total number of segments in project:

$numofsegments2 = InputBox ("Confirm number of segments", "Please confirm the total number of segments in your project", $numofsegments, "", 200, 200)
$numofsegmentsplus = $numofsegments2 + 3

; Exit OmegaT:

WinActivate ("OmegaT", "")
WinWaitActive ("OmegaT", "")

Send ("!p")
Send ("c")
Send ("^q")

Sleep (500)

; Replace current prefs file with our own prefs file:

FileCopy ("omegat.prefs", @AppDataDir & "\OmegaT\omegat.prefs", 1)

; Since OmegaT uses Java, and since Java can be installed just about anywhere,
; we must get the location of Java and then add some jar commands to it:

$javakey = RegRead("HKEY_LOCAL_MACHINE\SOFTWARE\Classes\Applications\javaw.exe\shell\open\command", "")
$omtprog = @ProgramFilesDir & "\OmegaT\OmegaT.jar"
$javakey2 = StringReplace ($javakey, """%1""", """" & $omtprog & """")
$javakey3 = StringTrimRight ($javakey2, 3)

; Run OmegaT, minimised:

Run ($javakey3, "", @SW_MINIMIZE)

While 1
If WinExists("OmegaT") Then
ExitLoop
EndIf
WEnd

; Activate OmT and dismiss Project Files window:

WinSetState ("OmegaT", "", @SW_RESTORE)

WinActivate ("OmegaT", "")
WinWaitActive ("OmegaT", "")

Send ("^o")
Sleep (500)
Send ("{HOME}")
Send ("+{END}")
Sleep (500)
ClipPut ($projectnamereal)
Send ("^v")
Sleep (500)
Send ("{ENTER}")
Sleep (1000)

$projload = MsgBox (0, "Wait for project load", "Click OK when the project has finished loading")

WinSetOnTop ("Wait for", "Click OK when", 1)

While 1
If $projload = 1 Then
ExitLoop
EndIf
WEnd

Sleep (500)
Send ("{ESC}")

; Now run through all segments

WinActivate ("OmegaT", "")
WinWaitActive ("OmegaT", "")

Sleep (500)

For $i = 1 to $numofsegmentsplus
Send ("{TAB}")
Sleep (100)
Next

Sleep (500)

; Save the project:

Send ("^s")

; Then exit OmT again for rollback:

WinActivate ("OmegaT", "")
WinWaitActive ("OmegaT", "")

Send ("!p")
Send ("c")
Send ("^q")

Sleep (500)

; Now copy the TMX file to the desktop:

FileCopy ($dfltomegat2 & "\project_save.tmx", @DesktopDir & "\untranslated.tmx", 1)

; Then rollback:

FileDelete (@AppDataDir & "\OmegaT\omegat.prefs")
FileCopy (@AppDataDir & "\OmegaT\omegat_prefs.rollback", @AppDataDir & "\OmegaT\omegat.prefs", 1)

MsgBox (0, "Done!", "Completed untranslated.tmx copied to your Desktop", 5)

Func MyExit()
    Exit 
EndFunc 

Exit
